@@ -4,9 +4,12 @@
 #ifndef WIN32
 #include <unistd.h>
 #include <string.h>
+#ifdef USE_TUXKART_STEREO
+/* this brakes other archs */
 #include <sys/io.h>
 #include <sys/perm.h>                                                           
 #endif
+#endif
 
 static unsigned int lastKeystroke = 0 ;
 
@@ -136,7 +139,8 @@ void GFX::done ()
   glVertex3f ( 0, 0, 0 ) ;
   glEnd () ;
   glFlush () ;
-
+#ifdef USE_TUXKART_STEREO
+  /* this barfs on archs other than x86 */
   static int firsttime = TRUE ;
 
   if ( firsttime )
@@ -171,6 +175,7 @@ void GFX::done ()
     outb ( (stereo==-1) ? ~3 : ~2, LPBASE+2 ) ;
     stereo = -stereo ;
   }
+#endif  
 }
 
 
